/*
 * @Author: Kane
 * @Date: 2023-09-06 10:41:34
 * @LastEditors: Kane
 * @FilePath: /desktop_archievement_backend/src/main/java/com/cpic/xim/web/controllers/rewards/RewardController.java
 * @Description: 坐席奖励相关的请求
 * 
 * Copyright (c) ${2022} by Kane, All Rights Reserved. 
 */
package com.cpic.xim.web.controllers.rewards;

import java.io.IOException;
import java.util.ArrayList;
import org.apache.ibatis.session.SqlSession;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.cpic.xim.mybatis.mapper.RewardsMapper;
import com.cpic.xim.mybatis.pojo.RewardGainer;
import com.cpic.xim.mybatis.pojo.RewardProject;
import com.cpic.xim.mybatis.utils.MybatisUtils;

@Controller
@RequestMapping( "/rewards" )
public class RewardController
{
    // 日志
    private static Logger logger = LoggerFactory.getLogger( RewardController.class );

    private RewardController()
    {}

    /**
     * 相应查询获奖项目清单的请求
     * @return 获奖项目清单的response对象
     */
    @PostMapping( "/query_reward_projects.do" )
    @ResponseBody
    public RewardProjectsResponse queryRewardProjecrts()
    {
        RewardProjectsResponse response = new RewardProjectsResponse();

        SqlSession session = null;

        logger.debug( "查询奖项清单。" );

        try
        {
            session = MybatisUtils.getSqlSession();

            RewardsMapper mapper = session.getMapper( RewardsMapper.class );
            ArrayList<RewardProject> rewards = mapper.queryRewardProjects();

            response.setSuccess( true );
            response.setMessage( "查询成功！" );
            response.setRewardList( rewards );

            logger.debug( "查询奖项清单，" + response.getMessage() + "，" + rewards.toString() );
        }
        catch ( IOException error )
        {
            response.setSuccess( false );
            response.setMessage( "查询失败！" + error.getMessage() );
            response.setRewardList( null );

            logger.debug( "查询奖项清单，" + response.getMessage() + "，" + error.getMessage() );
        }
        finally
        {
            if ( session != null )
            {
                session.close();
            }
        }

        return response;
    }

    @PostMapping( "/query_reward_gainers.do" )
    @ResponseBody
    RewardGainersResponse queryRewardGainers()
    {
        RewardGainersResponse response = new RewardGainersResponse();
        SqlSession session = null;

        try
        {
            session = MybatisUtils.getSqlSession();

            RewardsMapper mapper = session.getMapper( RewardsMapper.class );

            ArrayList<RewardGainer> gainers = mapper.queryRewardTelsaler();

            response.setSuccess( true );
            response.setMessage( "查询成功！" );
            response.setGainerList( gainers );
        }
        catch ( IOException error )
        {
            response.setSuccess( false );
            response.setMessage( "查询失败！" + error.getMessage() );
            response.setGainerList( null );
        }
        finally
        {
            if ( session != null )
            {
                session.close();
            }
        }

        return response;
    }
}
